leaftools.get_leaf_in_expr_with_maximum_duration
================================================

.. autofunction:: abjad.tools.leaftools.get_leaf_in_expr_with_maximum_duration.get_leaf_in_expr_with_maximum_duration
   :noindex:
